@@ -24,6 +24,10 @@ changed
 """
 
 # imports
+import digitalio
+import board
 
-__version__ = "0.0.3"
+__version__ = "0.0.4"
 __repo__ = "https://github.com/foamyguy/Foamyguy_CircuitPython_Version_Testing.git"
+
+the_pin = digitalio.DigitalInOut(board.D1)
